<?php
/*  Copyright 2007  FunnyDingo  (email : funnydingo@funnydingo.de)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*
Plugin Name: New Tag Cloud
Plugin URI: http://www.funnydingo.de/projekte/new-tag-cloud/
Description: The plugin provides an widget wich shows a tag cloud with the tags used by the new WordPress own tagging feature
Author: Dennis Hueckelheim aka FunnyDingo
Version: 0.1
Author URI: http://www.funnydingo.de/
*/

$newtagcloud_defaults = array(
	'maxcount'		=> 10,
	'title'			=> 'New Tag Cloud',
	'bigsize'		=> 18,
	'smallsize'		=> 10,
	'step'			=> 2,
	'sizetype'		=> 'px'
);

function newtagcloud_output()
{
	global $newtagcloud_defaults, $wpdb;
	$options = (array) get_option('widget_newtagcloud');
	$options['title'] = (strlen($options['title']) >= 1) ? $options['title'] : $newtagcloud_defaults['title'];
	$options['maxcount'] = intval($options['maxcount']) >= 1 ? $options['maxcount'] : intval($newtagcloud_defaults['maxcount']);
	$options['bigsize'] = intval($options['bigsize']) >= 1 ? $options['bigsize'] : $newtagcloud_defaults['bigsize'];
	$options['smallsize'] = intval($options['smallsize']) >= 1 ? $options['smallsize'] : $newtagcloud_defaults['smallsize'];
	$options['step'] = intval($options['step']) >= 1 ? $options['step'] : $newtagcloud_defaults['step'];
	$options['sizetype'] = (strlen($options['sizetype']) >= 1) ? $options['sizetype'] : $newtagcloud_defaults['sizetype'];

	$content = array();
	$size = $options['bigsize'];

	$terms = $wpdb->get_results("SELECT $wpdb->terms.term_id, $wpdb->terms.name, count FROM $wpdb->term_taxonomy INNER JOIN $wpdb->terms ON $wpdb->terms.term_id = $wpdb->term_taxonomy.term_id WHERE taxonomy = 'post_tag' ORDER BY count DESC LIMIT 0, " . $options['maxcount']);

	$prevCount = $terms[0]->count;
	foreach ($terms as $term)
	{
		if ($prevCount > intval($term->count) && $size > $options['smallsize'])
		{
			$size = $size - $options['step'];
			$prevCount = intval($term->count);
		}
		$content[$term->name] = '<a style="font-size:' . $size . $options['sizetype']. '" href="' . get_tag_link($term->term_id) . '">' . $term->name . '</a>';
	}
	ksort($content);
	$content = implode(" ", $content);
	echo '<h2>' . $options['title'] . '</h2><ul id="newtagcloud"><li>' . $content . '</li></ul>';
}





function widget_newtagcloud_control()
{
	global $newtagcloud_defaults;
	if ($_POST['newtagcloud-submit'])
	{
		$newoptions['title'] = strip_tags(stripslashes($_POST['newtagcloud-title']));
		$newoptions['maxcount'] = intval($_POST['newtagcloud-maxcount']);
		$newoptions['bigsize'] = intval($_POST['newtagcloud-bigsize']);
		$newoptions['smallsize'] = intval($_POST['newtagcloud-smallsize']);
		$newoptions['step'] = intval($_POST['newtagcloud-step']);
		$newoptions['sizetype'] = strip_tags(stripslashes($_POST['newtagcloud-sizetype']));
		update_option('widget_newtagcloud', $newoptions);
	}
	$options = $newoptions = get_option('widget_newtagcloud');
	$title = (strlen($options['title']) >= 1) ? $options['title'] : $newtagcloud_defaults['title'];
	$maxcount = intval($options['maxcount']) >= 1 ? $options['maxcount'] : $newtagcloud_defaults['maxcount'];
	$bigsize = intval($options['bigsize']) >= 1 ? $options['bigsize'] : $newtagcloud_defaults['bigsize'];
	$smallsize = intval($options['smallsize']) >= 1 ? $options['smallsize'] : $newtagcloud_defaults['smallsize'];
	$step = intval($options['step']) >= 1 ? $options['step'] : $newtagcloud_defaults['step'];
	$sizetype = (strlen($options['sizetype']) >= 1) ? $options['sizetype'] : $newtagcloud_defaults['sizetype'];
	echo '<p style="text-align:right;"><label for="newtagcloud-title">Title: <input style="width: 250px;" id="newtagcloud-title" name="newtagcloud-title" type="text" value="'.$title.'" /></label></p>';
	echo '<p style="text-align:right;"><label for="newtagcloud-maxcount">Max entries: <input style="width: 250px;" id="newtagcloud-maxcount" name="newtagcloud-maxcount" type="text" value="'.$maxcount.'" /></label></p>';
	echo '<p style="text-align:right;"><label for="newtagcloud-bigsize">Biggest font size (px): <input style="width: 250px;" id="newtagcloud-bigsize" name="newtagcloud-bigsize" type="text" value="'.$bigsize.'" /></label></p>';
	echo '<p style="text-align:right;"><label for="newtagcloud-smallsize">Smalltes font size (px): <input style="width: 250px;" id="newtagcloud-smallsize" name="newtagcloud-smallsize" type="text" value="'.$smallsize.'" /></label></p>';
	echo '<p style="text-align:right;"><label for="newtagcloud-step">Font size stepping: <input style="width: 250px;" id="newtagcloud-step" name="newtagcloud-step" type="text" value="'.$step.'" /></label></p>';
	echo '<p style="text-align:right;"><label for="newtagcloud-sizetype">Font type (px, em, ...): <input style="width: 250px;" id="newtagcloud-sizetype" name="newtagcloud-sizetype" type="text" value="'.$sizetype.'" /></label></p>';
	echo '<input type="hidden" id="newtagcloud-submit" name="newtagcloud-submit" value="1" />';
}

function widget_newtagcloud_init()
{
	// Check for the required API functions
	if ( !function_exists('register_sidebar_widget') || !function_exists('register_widget_control') )
		return;

	// This prints the widget
	function widget_newtagcloud($args) {
		extract($args);
		?>
		<?php echo $before_widget; ?>
		<?php echo newtagcloud_output(); ?>
		<?php echo $after_widget; ?>
<?php
	}

	// Tell Dynamic Sidebar about our new widget and its control
	register_sidebar_widget(array('New Tag Cloud', 'widgets'), 'widget_newtagcloud');
	register_widget_control(array('New Tag Cloud', 'widgets'), 'widget_newtagcloud_control', 420, 210);
}

// Delay plugin execution to ensure Dynamic Sidebar has a chance to load first
add_action('widgets_init', 'widget_newtagcloud_init');

?>
